Learn R Programming

dclone (version 1.5-0)

lambdamax.diag: Maximum Eigenvalue of the Posterior Variance-Covariance Matrix

Description

Calculates the maximum eigenvalue of the posterior variance-covariance matrix

Usage

lambdamax.diag(x)
chisq.diag(x)

Arguments

x
An object of class mcmc or mcmc.list.

Value

  • lambdamax.diag returns a single vaue, the maximum of the eigenvalues of the unscaled variance covariance matrix of the estimated parameters. chisq.diag returns

encoding

UTF-8

Details

This diagnostics can be used to test for the data cloning convergence (Lele et al. 2007, 2010). Asymptotically the posterior distribution of the parameters approaches a degenerate multivariate normal distribution. As the distribution is getting more degenerate, the maximal eigenvalue ($\lambda_{max}$) of the unscaled covariance matrix is decreasing. There is no critical value under which $\lambda_{max}$ is good enough. By default, 0.05 is used (see getOption("dclone")$diag). Another diagnostic tool is to check if the joint posterior distribution is multivariate normal. It is done by chisq.diag as described by Lele et al. (2010).

References

Lele, S.R., B. Dennis and F. Lutscher, 2007. Data cloning: easy maximum likelihood estimation for complex ecological models using Bayesian Markov chain Monte Carlo methods. Ecology Letters 10, 551--563. Lele, S. R., K. Nadeem and B. Schmuland, 2010. Estimability and likelihood inference for generalized linear mixed models using data cloning. Journal of the American Statistical Association 105, 1617--1625. Solymos, P., 2010. dclone: Data Cloning in R. The R Journal 2(2), 29--37. URL: http://journal.r-project.org/archive/2010-2/RJournal_2010-2_Solymos.pdf

See Also

Eigen decomposition: eigen

Examples

Run this code
data(regmod)
lambdamax.diag(regmod)
chisq.diag(regmod)

Run the code above in your browser using DataLab