lambdamax.diag(x)
chisq.diag(x)mcmc or mcmc.list.lambdamax.diag returns a single vaue, the maximum of the eigenvalues of the
unscaled variance covariance matrix of the estimated parameters.
chisq.diag returnsgetOption("dclone")$diag).
Another diagnostic tool is to check if the joint posterior distribution is
multivariate normal. It is done by chisq.diag as described by
Lele et al. (2010).eigendata(regmod)
lambdamax.diag(regmod)
chisq.diag(regmod)Run the code above in your browser using DataLab